@@ -84,11 +84,13 @@ struct _GeditPreferencesDialogPrivate
 	/* Font */
 	GtkWidget	*default_font_checkbutton;
 	GtkWidget	*font_button;
-	GtkWidget	*font_hbox;
+	GtkWidget	*font_grid;
 
 	/* Style Scheme */
 	GtkListStore	*schemes_treeview_model;
 	GtkWidget	*schemes_treeview;
+	GtkTreeViewColumn *schemes_column;
+	GtkCellRenderer *schemes_renderer;
 	GtkWidget	*install_scheme_button;
 	GtkWidget	*uninstall_scheme_button;
 	GtkWidget	*schemes_scrolled_window;
@@ -406,7 +408,7 @@ on_use_default_font_changed (GSettings              *settings,
 
 	value = g_settings_get_boolean (settings, key);
 
-	gtk_widget_set_sensitive (dlg->priv->font_hbox, !value);
+	gtk_widget_set_sensitive (dlg->priv->font_grid, !value);
 }
 
 static void
@@ -447,7 +449,7 @@ setup_font_colors_page_font_section (GeditPreferencesDialog *dlg)
 				      use_default_font);
 
 	/* Set initial widget sensitivity */
-	gtk_widget_set_sensitive (dlg->priv->font_hbox, !use_default_font);
+	gtk_widget_set_sensitive (dlg->priv->font_grid, !use_default_font);
 
 	/* Connect signals */
 	g_signal_connect (dlg->priv->editor,
@@ -1059,41 +1061,19 @@ scheme_description_cell_data_func (GtkTreeViewColumn *column,
 static void
 setup_font_colors_page_style_scheme_section (GeditPreferencesDialog *dlg)
 {
-	GtkCellRenderer *renderer;
-	GtkTreeViewColumn *column;
+	GeditPreferencesDialogPrivate *priv = dlg->priv;
 	GtkTreeSelection *selection;
 	GtkStyleContext *context;
 	const gchar *def_id;
 
 	gedit_debug (DEBUG_PREFS);
 
-	/* Create GtkListStore for styles & setup treeview. */
-	dlg->priv->schemes_treeview_model = gtk_list_store_new (NUM_COLUMNS,
-								G_TYPE_STRING,
-								G_TYPE_STRING,
-								G_TYPE_STRING,
-								G_TYPE_STRING);
-
-	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (dlg->priv->schemes_treeview_model),
-					      0,
-					      GTK_SORT_ASCENDING);
-	gtk_tree_view_set_model (GTK_TREE_VIEW (dlg->priv->schemes_treeview),
-				 GTK_TREE_MODEL (dlg->priv->schemes_treeview_model));
-
-	column = gtk_tree_view_column_new ();
-
-	renderer = gtk_cell_renderer_text_new ();
-	g_object_set (renderer, "ellipsize", PANGO_ELLIPSIZE_END, NULL);
-	gtk_tree_view_column_pack_start (column, renderer, TRUE);
-	gtk_tree_view_column_set_cell_data_func (column,
-						 renderer,
+	gtk_tree_view_column_set_cell_data_func (priv->schemes_column,
+						 priv->schemes_renderer,
 						 scheme_description_cell_data_func,
 						 dlg,
 						 NULL);
 
-	gtk_tree_view_append_column (GTK_TREE_VIEW (dlg->priv->schemes_treeview),
-				     column);
-
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (dlg->priv->schemes_treeview));
 	gtk_tree_selection_set_mode (selection, GTK_SELECTION_BROWSE);
 
@@ -1138,13 +1118,12 @@ setup_plugins_page (GeditPreferencesDialog *dlg)
 	gedit_debug (DEBUG_PREFS);
 
 	page_content = peas_gtk_plugin_manager_new (NULL);
+	gtk_widget_set_vexpand (GTK_WIDGET (page_content), TRUE);
+	gtk_widget_set_hexpand (GTK_WIDGET (page_content), TRUE);
 	g_return_if_fail (page_content != NULL);
 
-	gtk_box_pack_start (GTK_BOX (dlg->priv->plugin_manager_place_holder),
-			    page_content,
-			    TRUE,
-			    TRUE,
-			    0);
+	gtk_container_add (GTK_CONTAINER (dlg->priv->plugin_manager_place_holder),
+	                   page_content);
 
 	gtk_widget_show_all (page_content);
 }
@@ -1158,6 +1137,7 @@ gedit_preferences_dialog_init (GeditPreferencesDialog *dlg)
 		"adjustment1",
 		"adjustment2",
 		"adjustment3",
+		"schemes_treeview_model",
 		NULL
 	};
 
@@ -1175,7 +1155,7 @@ gedit_preferences_dialog_init (GeditPreferencesDialog *dlg)
 				NULL);
 
 	gtk_window_set_title (GTK_WINDOW (dlg), _("gedit Preferences"));
-	gtk_window_set_resizable (GTK_WINDOW (dlg), FALSE);
+	gtk_window_set_resizable (GTK_WINDOW (dlg), TRUE);
 	gtk_window_set_destroy_with_parent (GTK_WINDOW (dlg), TRUE);
 
 	/* HIG defaults */
@@ -1214,8 +1194,11 @@ gedit_preferences_dialog_init (GeditPreferencesDialog *dlg)
 	dlg->priv->auto_save_spinbutton = GTK_WIDGET (gtk_builder_get_object (builder, "auto_save_spinbutton"));
 	dlg->priv->default_font_checkbutton = GTK_WIDGET (gtk_builder_get_object (builder, "default_font_checkbutton"));
 	dlg->priv->font_button = GTK_WIDGET (gtk_builder_get_object (builder, "font_button"));
-	dlg->priv->font_hbox = GTK_WIDGET (gtk_builder_get_object (builder, "font_hbox"));
+	dlg->priv->font_grid = GTK_WIDGET (gtk_builder_get_object (builder, "font_grid"));
+	dlg->priv->schemes_treeview_model = GTK_LIST_STORE (gtk_builder_get_object (builder, "schemes_treeview_model"));
 	dlg->priv->schemes_treeview = GTK_WIDGET (gtk_builder_get_object (builder, "schemes_treeview"));
+	dlg->priv->schemes_column = GTK_TREE_VIEW_COLUMN (gtk_builder_get_object (builder, "schemes_column"));
+	dlg->priv->schemes_renderer = GTK_CELL_RENDERER (gtk_builder_get_object (builder, "schemes_renderer"));
 	dlg->priv->schemes_scrolled_window = GTK_WIDGET (gtk_builder_get_object (builder, "schemes-scrolled-window"));
 	dlg->priv->install_scheme_button = GTK_WIDGET (gtk_builder_get_object (builder, "install_scheme_button"));
 	dlg->priv->uninstall_scheme_button = GTK_WIDGET (gtk_builder_get_object (builder, "uninstall_scheme_button"));
@@ -1224,7 +1207,7 @@ gedit_preferences_dialog_init (GeditPreferencesDialog *dlg)
 	g_object_unref (builder);
 
 	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dlg))),
-			    dlg->priv->notebook, FALSE, FALSE, 0);
+			    dlg->priv->notebook, TRUE, TRUE, 0);
 	g_object_unref (dlg->priv->notebook);
 	gtk_container_set_border_width (GTK_CONTAINER (dlg->priv->notebook), 5);
 
