@@ -299,244 +299,6 @@ on_auto_save_interval_changed (GSettings     *settings,
 	g_list_free (docs);
 }
 
-static void
-on_undo_actions_limit_changed (GSettings     *settings,
-			       const gchar   *key,
-			       GeditSettings *gs)
-{
-	GList *docs, *l;
-	gint ul;
-
-	ul = g_settings_get_int (settings, key);
-
-	ul = CLAMP (ul, -1, 250);
-
-	docs = gedit_app_get_documents (GEDIT_APP (g_application_get_default ()));
-
-	for (l = docs; l != NULL; l = g_list_next (l))
-	{
-		gtk_source_buffer_set_max_undo_levels (GTK_SOURCE_BUFFER (l->data),
-						       ul);
-	}
-
-	g_list_free (docs);
-}
-
-static void
-on_wrap_mode_changed (GSettings     *settings,
-		      const gchar   *key,
-		      GeditSettings *gs)
-{
-	GtkWrapMode wrap_mode;
-	GList *views, *l;
-
-	wrap_mode = g_settings_get_enum (settings, key);
-
-	views = gedit_app_get_views (GEDIT_APP (g_application_get_default ()));
-
-	for (l = views; l != NULL; l = g_list_next (l))
-	{
-		gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (l->data),
-					     wrap_mode);
-	}
-
-	g_list_free (views);
-}
-
-static void
-on_tabs_size_changed (GSettings     *settings,
-		      const gchar   *key,
-		      GeditSettings *gs)
-{
-	GList *views, *l;
-	guint ts;
-
-	g_settings_get (settings, key, "u", &ts);
-
-	ts = CLAMP (ts, 1, 24);
-
-	views = gedit_app_get_views (GEDIT_APP (g_application_get_default ()));
-
-	for (l = views; l != NULL; l = g_list_next (l))
-	{
-		gtk_source_view_set_tab_width (GTK_SOURCE_VIEW (l->data),
-					       ts);
-	}
-
-	g_list_free (views);
-}
-
-static void
-on_insert_spaces_changed (GSettings     *settings,
-			  const gchar   *key,
-			  GeditSettings *gs)
-{
-	GList *views, *l;
-	gboolean spaces;
-
-	spaces = g_settings_get_boolean (settings, key);
-
-	views = gedit_app_get_views (GEDIT_APP (g_application_get_default ()));
-
-	for (l = views; l != NULL; l = g_list_next (l))
-	{
-		gtk_source_view_set_insert_spaces_instead_of_tabs (
-					GTK_SOURCE_VIEW (l->data),
-					spaces);
-	}
-
-	g_list_free (views);
-}
-
-static void
-on_auto_indent_changed (GSettings     *settings,
-			const gchar   *key,
-			GeditSettings *gs)
-{
-	GList *views, *l;
-	gboolean enable;
-
-	enable = g_settings_get_boolean (settings, key);
-
-	views = gedit_app_get_views (GEDIT_APP (g_application_get_default ()));
-
-	for (l = views; l != NULL; l = g_list_next (l))
-	{
-		gtk_source_view_set_auto_indent (GTK_SOURCE_VIEW (l->data),
-						 enable);
-	}
-
-	g_list_free (views);
-}
-
-static void
-on_display_line_numbers_changed (GSettings     *settings,
-				 const gchar   *key,
-				 GeditSettings *gs)
-{
-	GList *views, *l;
-	gboolean line_numbers;
-
-	line_numbers = g_settings_get_boolean (settings, key);
-
-	views = gedit_app_get_views (GEDIT_APP (g_application_get_default ()));
-
-	for (l = views; l != NULL; l = g_list_next (l))
-	{
-		gtk_source_view_set_show_line_numbers (GTK_SOURCE_VIEW (l->data),
-						       line_numbers);
-	}
-
-	g_list_free (views);
-}
-
-static void
-on_hl_current_line_changed (GSettings     *settings,
-			    const gchar   *key,
-			    GeditSettings *gs)
-{
-	GList *views, *l;
-	gboolean hl;
-
-	hl = g_settings_get_boolean (settings, key);
-
-	views = gedit_app_get_views (GEDIT_APP (g_application_get_default ()));
-
-	for (l = views; l != NULL; l = g_list_next (l))
-	{
-		gtk_source_view_set_highlight_current_line (GTK_SOURCE_VIEW (l->data),
-							    hl);
-	}
-
-	g_list_free (views);
-}
-
-static void
-on_bracket_matching_changed (GSettings     *settings,
-			     const gchar   *key,
-			     GeditSettings *gs)
-{
-	GList *docs, *l;
-	gboolean enable;
-
-	enable = g_settings_get_boolean (settings, key);
-
-	docs = gedit_app_get_documents (GEDIT_APP (g_application_get_default ()));
-
-	for (l = docs; l != NULL; l = g_list_next (l))
-	{
-		gtk_source_buffer_set_highlight_matching_brackets (GTK_SOURCE_BUFFER (l->data),
-								   enable);
-	}
-
-	g_list_free (docs);
-}
-
-static void
-on_display_right_margin_changed (GSettings     *settings,
-				 const gchar   *key,
-				 GeditSettings *gs)
-{
-	GList *views, *l;
-	gboolean display;
-
-	display = g_settings_get_boolean (settings, key);
-
-	views = gedit_app_get_views (GEDIT_APP (g_application_get_default ()));
-
-	for (l = views; l != NULL; l = g_list_next (l))
-	{
-		gtk_source_view_set_show_right_margin (GTK_SOURCE_VIEW (l->data),
-						       display);
-	}
-
-	g_list_free (views);
-}
-
-static void
-on_right_margin_position_changed (GSettings     *settings,
-				  const gchar   *key,
-				  GeditSettings *gs)
-{
-	GList *views, *l;
-	gint pos;
-
-	g_settings_get (settings, key, "u", &pos);
-
-	pos = CLAMP (pos, 1, 160);
-
-	views = gedit_app_get_views (GEDIT_APP (g_application_get_default ()));
-
-	for (l = views; l != NULL; l = g_list_next (l))
-	{
-		gtk_source_view_set_right_margin_position (GTK_SOURCE_VIEW (l->data),
-							   pos);
-	}
-
-	g_list_free (views);
-}
-
-static void
-on_smart_home_end_changed (GSettings     *settings,
-			   const gchar   *key,
-			   GeditSettings *gs)
-{
-	GtkSourceSmartHomeEndType smart_he;
-	GList *views, *l;
-
-	smart_he = g_settings_get_enum (settings, key);
-
-	views = gedit_app_get_views (GEDIT_APP (g_application_get_default ()));
-
-	for (l = views; l != NULL; l = g_list_next (l))
-	{
-		gtk_source_view_set_smart_home_end (GTK_SOURCE_VIEW (l->data),
-						    smart_he);
-	}
-
-	g_list_free (views);
-}
-
 static void
 on_syntax_highlighting_changed (GSettings     *settings,
 				const gchar   *key,
@@ -576,27 +338,6 @@ on_syntax_highlighting_changed (GSettings     *settings,
 	}
 }
 
-static void
-on_search_highlighting_changed (GSettings     *settings,
-				const gchar   *key,
-				GeditSettings *gs)
-{
-	GList *docs, *l;
-	gboolean enable;
-
-	enable = g_settings_get_boolean (settings, key);
-
-	docs = gedit_app_get_documents (GEDIT_APP (g_application_get_default ()));
-
-	for (l = docs; l != NULL; l = g_list_next (l))
-	{
-		gedit_document_set_enable_search_highlighting  (GEDIT_DOCUMENT (l->data),
-								enable);
-	}
-
-	g_list_free (docs);
-}
-
 static void
 gedit_settings_init (GeditSettings *gs)
 {
@@ -642,58 +383,10 @@ gedit_settings_init (GeditSettings *gs)
 			  "changed::auto-save-interval",
 			  G_CALLBACK (on_auto_save_interval_changed),
 			  gs);
-	g_signal_connect (gs->priv->editor,
-			  "changed::undo-actions-limit",
-			  G_CALLBACK (on_undo_actions_limit_changed),
-			  gs);
-	g_signal_connect (gs->priv->editor,
-			  "changed::wrap-mode",
-			  G_CALLBACK (on_wrap_mode_changed),
-			  gs);
-	g_signal_connect (gs->priv->editor,
-			  "changed::tabs-size",
-			  G_CALLBACK (on_tabs_size_changed),
-			  gs);
-	g_signal_connect (gs->priv->editor,
-			  "changed::insert-spaces",
-			  G_CALLBACK (on_insert_spaces_changed),
-			  gs);
-	g_signal_connect (gs->priv->editor,
-			  "changed::auto-indent",
-			  G_CALLBACK (on_auto_indent_changed),
-			  gs);
-	g_signal_connect (gs->priv->editor,
-			  "changed::display-line-numbers",
-			  G_CALLBACK (on_display_line_numbers_changed),
-			  gs);
-	g_signal_connect (gs->priv->editor,
-			  "changed::highlight-current-line",
-			  G_CALLBACK (on_hl_current_line_changed),
-			  gs);
-	g_signal_connect (gs->priv->editor,
-			  "changed::bracket-matching",
-			  G_CALLBACK (on_bracket_matching_changed),
-			  gs);
-	g_signal_connect (gs->priv->editor,
-			  "changed::display-right-margin",
-			  G_CALLBACK (on_display_right_margin_changed),
-			  gs);
-	g_signal_connect (gs->priv->editor,
-			  "changed::right-margin-position",
-			  G_CALLBACK (on_right_margin_position_changed),
-			  gs);
-	g_signal_connect (gs->priv->editor,
-			  "changed::smart-home-end",
-			  G_CALLBACK (on_smart_home_end_changed),
-			  gs);
 	g_signal_connect (gs->priv->editor,
 			  "changed::syntax-highlighting",
 			  G_CALLBACK (on_syntax_highlighting_changed),
 			  gs);
-	g_signal_connect (gs->priv->editor,
-			  "changed::search-highlighting",
-			  G_CALLBACK (on_search_highlighting_changed),
-			  gs);
 }
 
 static void
